diff --git a/CMakeLists.txt b/CMakeLists.txt
index f62ddbdf0139e68c4a5a56a6ab37847562ca39b4..3e2dbdeef5fbff6177398b7c53bdc4308da171f1 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -230,11 +230,10 @@ cmake_dependent_option(CHAMELEON_USE_HIP_ROC
                     "Enable HIP kernels with ROCclr backend" OFF
                     "CHAMELEON_ENABLE_HIP" OFF)
 
-set(CHAMELEON_USE_HIP OFF CACHE INTERNAL "Equivalent to CHAMELEON_USE_CUDA for HIP. Enabled only of one of the CHAMELEON_USE_HIP{CUDA,ROC} is enabled")
 if( CHAMELEON_USE_HIP_CUDA OR CHAMELEON_USE_HIP_ROC )
-  set(CHAMELEON_USE_HIP ON)
+    set(CHAMELEON_USE_HIP ON CACHE INTERNAL "Equivalent to CHAMELEON_USE_CUDA for HIP. Enabled only of one of the CHAMELEON_USE_HIP{CUDA,ROC} is enabled" FORCE)
 else()
-  set(CHAMELEON_USE_HIP OFF)
+    set(CHAMELEON_USE_HIP OFF CACHE INTERNAL "Equivalent to CHAMELEON_USE_CUDA for HIP. Enabled only of one of the CHAMELEON_USE_HIP{CUDA,ROC} is enabled" FORCE)
 endif()
 
 # Enable Hmat-OSS kernels
@@ -690,18 +689,18 @@ set(CHAMELEON_SOURCES_TARGETS "" CACHE INTERNAL "List of targets of sources")
 
 if (NOT CHAMELEON_SIMULATION)
   ###############################################################################
-  # Coreblas library (kernels for CPUs) #
-  #######################################
+  # coreblas library (kernels for CPUs, interface to cblas/lapacke) #
+  ###################################################################
   add_subdirectory(coreblas)
 
   ###############################################################################
-  # Cudablas library (kernels for CUDAs) #
-  ########################################
+  # gpucublas library (kernels for GPUs, interface to cublas or hibblas) #
+  ########################################################################
   if(CHAMELEON_USE_CUDA)
-    add_subdirectory(cudablas)
+    add_subdirectory(gpucublas)
   endif()
   if(CHAMELEON_USE_HIP)
-    add_subdirectory(hipblas)
+    add_subdirectory(gpuhipblas)
   endif()
 
 endif()
diff --git a/cmake_modules/CHAMELEONConfig.cmake.in b/cmake_modules/CHAMELEONConfig.cmake.in
index eda084878196ed0ee9b08ad9ed45b98d35d42103..9bc029786004c25d85a6fe8a8a4731a6e0bff74b 100644
--- a/cmake_modules/CHAMELEONConfig.cmake.in
+++ b/cmake_modules/CHAMELEONConfig.cmake.in
@@ -50,7 +50,10 @@ if (NOT @CHAMELEON_SIMULATION@)
   include("${CMAKE_CURRENT_LIST_DIR}/coreblasTargets.cmake")
 endif()
 if (@CHAMELEON_USE_CUDA@ AND NOT @CHAMELEON_SIMULATION@)
-  include("${CMAKE_CURRENT_LIST_DIR}/cudablasTargets.cmake")
+  include("${CMAKE_CURRENT_LIST_DIR}/gpucublasTargets.cmake")
+endif()
+if (@CHAMELEON_USE_HIP@ AND NOT @CHAMELEON_SIMULATION@)
+  include("${CMAKE_CURRENT_LIST_DIR}/gpuhipblasTargets.cmake")
 endif()
 if (@CHAMELEON_SCHED_OPENMP@)
   include("${CMAKE_CURRENT_LIST_DIR}/chameleon_openmpTargets.cmake")
diff --git a/compute/CMakeLists.txt b/compute/CMakeLists.txt
index bed4df6f140c9449d7c7201bf4249373c14d6146..1f18046a4894d1a5e5871967c33c1c744b1998a3 100644
--- a/compute/CMakeLists.txt
+++ b/compute/CMakeLists.txt
@@ -344,13 +344,13 @@ if (CHAMELEON_USE_MPI)
 endif()
 if (CHAMELEON_USE_CUDA)
   if (NOT CHAMELEON_SIMULATION)
-    target_link_libraries(chameleon PUBLIC cudablas)
+    target_link_libraries(chameleon PUBLIC gpucublas)
     target_link_libraries(chameleon PUBLIC CUDA::CUBLAS)
   endif()
 endif()
 if (CHAMELEON_USE_HIP)
   if (NOT CHAMELEON_SIMULATION)
-    target_link_libraries(chameleon PUBLIC hipblas)
+    target_link_libraries(chameleon PUBLIC gpuhipblas)
     target_link_libraries(chameleon PUBLIC HIP::HIPBLAS)
   endif()
 endif()
diff --git a/doc/dev/main.dox b/doc/dev/main.dox
index e4ee8ecbd42362f581169c95db3623d3ae2f39c6..d8f7320949a8d92785cfdd0e2b37222937bca7f4 100644
--- a/doc/dev/main.dox
+++ b/doc/dev/main.dox
@@ -67,10 +67,10 @@ The libraries are organized as follows :
 
 - __chameleon_quark|openmp|parsec|starpu__ : interface to the
   different runtimes, depends on "coreblas" and optionally on
-  "cudablas" and on a runtime system library
+  "gpucublas" or "gpuhiblas" and on a runtime system library
 
-- __coreblas__ and __cudablas__ : interfaces to the CPU and GPU
-  kernels
+- __coreblas__ and __gpucublas__ or __gpuhipblas__ :
+  interfaces to the CPU and GPU kernels
 
 - __hqr__ : HQR is a C library providing tools to generate hierachical
   trees adapted to 2D block-cyclic data distribution and algorithms
@@ -91,14 +91,16 @@ Lets have a look to the source code organization in directories.
 
 - __coreblas__ : the Chameleon interface to CPU linear algebra kernels
 
-- __cudablas__ : the Chameleon interface to GPU linear algebra kernels
-
 - __distrib__ : some hints to install Chameleon's dependencies
 
 - __doc__ : users and developers documentations
 
 - __example__ : couple of C files to show how to use Chameleon
 
+- __gpucublas__ : the Chameleon interface to GPU linear algebra kernels (cublas)
+
+- __gpuhipblas__ : the Chameleon interface to GPU linear algebra kernels (hipblas)
+
 - __hqr__ : [HQR](https://gitlab.inria.fr/solverstack/hqr) is a C
 library providing tools to generate hierachical trees adapted to 2D
 block-cyclic data distribution and algorithms based on tiled
@@ -106,6 +108,8 @@ QR/algorithms
 
 - __include__ : Chameleon's headers file necessary for users
 
+- __lapack_api__ : the Chameleon interface CBLAS/LAPACKE like
+
 - __lib__ : material related to the distribution
 
 - __plasma-conversion__ : scripts to convert plasma task based
diff --git a/cudablas/CMakeLists.txt b/gpucublas/CMakeLists.txt
similarity index 100%
rename from cudablas/CMakeLists.txt
rename to gpucublas/CMakeLists.txt
diff --git a/cudablas/compute/CMakeLists.txt b/gpucublas/compute/CMakeLists.txt
similarity index 67%
rename from cudablas/compute/CMakeLists.txt
rename to gpucublas/compute/CMakeLists.txt
index 5389d35fdcc459ebb8783635eed79dc840160e64..d7a745c0489c3364398267f64513737a9348d9a3 100644
--- a/cudablas/compute/CMakeLists.txt
+++ b/gpucublas/compute/CMakeLists.txt
@@ -27,7 +27,7 @@
 
 # Generate the chameleon sources for all possible precisions
 # ------------------------------------------------------
-set(CUDABLAS_SRCS_GENERATED "")
+set(GPUCUBLAS_SRCS_GENERATED "")
 set(ZSRC
     cuda_zgeadd.c
     cuda_zgemerge.c
@@ -72,46 +72,46 @@ set(ZSRC
 # endif()
 
 precisions_rules_py(
-  CUDABLAS_SRCS_GENERATED "${ZSRC}"
+  GPUCUBLAS_SRCS_GENERATED "${ZSRC}"
   PRECISIONS "${CHAMELEON_PRECISION}")
 
-set(CUDABLAS_SRCS
-  ${CUDABLAS_SRCS_GENERATED}
+set(GPUCUBLAS_SRCS
+  ${GPUCUBLAS_SRCS_GENERATED}
   cudaglobal.c
   )
 
 # Force generation of sources
 # ---------------------------
-add_custom_target(cudablas_sources ALL SOURCES ${CUDABLAS_SRCS})
-set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};cudablas_sources" CACHE INTERNAL "List of targets of sources")
+add_custom_target(gpucublas_sources ALL SOURCES ${GPUCUBLAS_SRCS})
+set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};gpucublas_sources" CACHE INTERNAL "List of targets of sources")
 
 # Compile step
 # ------------
-add_library(cudablas ${CUDABLAS_SRCS})
-set_target_properties(cudablas PROPERTIES VERSION ${CHAMELEON_VERSION})
-set_target_properties(cudablas PROPERTIES SOVERSION ${CHAMELEON_VERSION_MAJOR})
-add_dependencies(cudablas cudablas_include cudablas_sources)
-target_include_directories(cudablas PUBLIC
-  $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/cudablas/include>
-  $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/cudablas/include>
+add_library(gpucublas ${GPUCUBLAS_SRCS})
+set_target_properties(gpucublas PROPERTIES VERSION ${CHAMELEON_VERSION})
+set_target_properties(gpucublas PROPERTIES SOVERSION ${CHAMELEON_VERSION_MAJOR})
+add_dependencies(gpucublas gpucublas_include gpucublas_sources)
+target_include_directories(gpucublas PUBLIC
+  $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/gpucublas/include>
+  $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/gpucublas/include>
   $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/include>
   $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/include>
   $<INSTALL_INTERFACE:include>)
-set_property(TARGET cudablas PROPERTY INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib")
+set_property(TARGET gpucublas PROPERTY INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib")
 
-target_link_libraries(cudablas PRIVATE coreblas CUDA::CUBLAS)
-target_link_libraries(cudablas PUBLIC MORSE::M)
+target_link_libraries(gpucublas PRIVATE coreblas CUDA::CUBLAS)
+target_link_libraries(gpucublas PUBLIC MORSE::M)
 
 # export target coreblas
-install(EXPORT cudablasTargets
+install(EXPORT gpucublasTargets
         NAMESPACE CHAMELEON::
         DESTINATION lib/cmake/chameleon
         )
 
 # installation
 # ------------
-install(TARGETS cudablas
-        EXPORT cudablasTargets
+install(TARGETS gpucublas
+        EXPORT gpucublasTargets
         ARCHIVE DESTINATION lib
         LIBRARY DESTINATION lib
         )
diff --git a/cudablas/compute/cuda_zgeadd.c b/gpucublas/compute/cuda_zgeadd.c
similarity index 99%
rename from cudablas/compute/cuda_zgeadd.c
rename to gpucublas/compute/cuda_zgeadd.c
index 1e9ff964e16cc5c4b71b749a857a17c99feec8a3..c3909cfbaf8c5d811d9101f7d2eb00a5a1566af7 100644
--- a/cudablas/compute/cuda_zgeadd.c
+++ b/gpucublas/compute/cuda_zgeadd.c
@@ -17,7 +17,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 /**
  ******************************************************************************
diff --git a/cudablas/compute/cuda_zgelqt.c b/gpucublas/compute/cuda_zgelqt.c
similarity index 99%
rename from cudablas/compute/cuda_zgelqt.c
rename to gpucublas/compute/cuda_zgelqt.c
index f02d024fa7474821d940fb001a50c78364764ec2..ad027da3a3a1d1150748144f7093501f7e83077d 100644
--- a/cudablas/compute/cuda_zgelqt.c
+++ b/gpucublas/compute/cuda_zgelqt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int CUDA_zgelqt(
diff --git a/cudablas/compute/cuda_zgemerge.c b/gpucublas/compute/cuda_zgemerge.c
similarity index 98%
rename from cudablas/compute/cuda_zgemerge.c
rename to gpucublas/compute/cuda_zgemerge.c
index 19caa2d6b858841bd7e82e241e503243dc3dd29d..e0c18d6da694adff8d35a7c060d697fd334f2caa 100644
--- a/cudablas/compute/cuda_zgemerge.c
+++ b/gpucublas/compute/cuda_zgemerge.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zgemerge( cham_side_t side, cham_diag_t diag,
diff --git a/cudablas/compute/cuda_zgemm.c b/gpucublas/compute/cuda_zgemm.c
similarity index 98%
rename from cudablas/compute/cuda_zgemm.c
rename to gpucublas/compute/cuda_zgemm.c
index 94ad85ef2cab838132be0cdf5484e801ee279fb8..e685b84c12c6edef080febf23a3abb4c849c22d1 100644
--- a/cudablas/compute/cuda_zgemm.c
+++ b/gpucublas/compute/cuda_zgemm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zgemm( cham_trans_t transa, cham_trans_t transb,
diff --git a/cudablas/compute/cuda_zgeqrt.c b/gpucublas/compute/cuda_zgeqrt.c
similarity index 99%
rename from cudablas/compute/cuda_zgeqrt.c
rename to gpucublas/compute/cuda_zgeqrt.c
index bcd273e48547f00a07919622aaf92bb4e31e7962..d24fa552c2e8f476c4134e20e8f10b21b400a09e 100644
--- a/cudablas/compute/cuda_zgeqrt.c
+++ b/gpucublas/compute/cuda_zgeqrt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int
diff --git a/cudablas/compute/cuda_zgessm.c b/gpucublas/compute/cuda_zgessm.c
similarity index 98%
rename from cudablas/compute/cuda_zgessm.c
rename to gpucublas/compute/cuda_zgessm.c
index 47c74fedf913c02b62dbc29b49dcad9153b64ee2..372b43a550b8f684a0bf2cce81f9daefc0c0e691 100644
--- a/cudablas/compute/cuda_zgessm.c
+++ b/gpucublas/compute/cuda_zgessm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 #if defined(HAVE_MAGMA_GETRF_INCPIV_GPU)
diff --git a/cudablas/compute/cuda_zgetrf.c b/gpucublas/compute/cuda_zgetrf.c
similarity index 98%
rename from cudablas/compute/cuda_zgetrf.c
rename to gpucublas/compute/cuda_zgetrf.c
index 1acfbfacdf401a4665569cc61deceb0602fb85d9..ec0bc305537477b3a295139c69c1eee20093fe75 100644
--- a/cudablas/compute/cuda_zgetrf.c
+++ b/gpucublas/compute/cuda_zgetrf.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 #if defined(HAVE_MAGMA_GETRF_INCPIV_GPU)
diff --git a/cudablas/compute/cuda_zhemm.c b/gpucublas/compute/cuda_zhemm.c
similarity index 98%
rename from cudablas/compute/cuda_zhemm.c
rename to gpucublas/compute/cuda_zhemm.c
index 60d9dc364ec607e412e1ebfe58145aded775ae05..b832596ad9b0fef1c0dd5cd4c0bbaf893b71ff80 100644
--- a/cudablas/compute/cuda_zhemm.c
+++ b/gpucublas/compute/cuda_zhemm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zhemm( cham_side_t side, cham_uplo_t uplo,
diff --git a/cudablas/compute/cuda_zher2k.c b/gpucublas/compute/cuda_zher2k.c
similarity index 98%
rename from cudablas/compute/cuda_zher2k.c
rename to gpucublas/compute/cuda_zher2k.c
index a8b4c627401852d7f90089a98ec4d83970887b2a..c0dc2c7e7ea5da560d0e8fdcbc4a1b6c9a898a77 100644
--- a/cudablas/compute/cuda_zher2k.c
+++ b/gpucublas/compute/cuda_zher2k.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zher2k( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zherfb.c b/gpucublas/compute/cuda_zherfb.c
similarity index 82%
rename from cudablas/compute/cuda_zherfb.c
rename to gpucublas/compute/cuda_zherfb.c
index ea486cc59d4c9a9274811f50f2154031195a679b..aa550c87ccc3d3df75d5ef181de46402aefc954a 100644
--- a/cudablas/compute/cuda_zherfb.c
+++ b/gpucublas/compute/cuda_zherfb.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zherfb( cham_uplo_t uplo, int n,
@@ -31,35 +31,35 @@ CUDA_zherfb( cham_uplo_t uplo, int n,
 {
     /* Check input arguments */
     if ((uplo != ChamUpper) && (uplo != ChamLower)) {
-        cudablas_error(1, "Illegal value of uplo");
+        gpucublas_error(1, "Illegal value of uplo");
         return -1;
     }
     if (n < 0) {
-        cudablas_error(2, "Illegal value of n");
+        gpucublas_error(2, "Illegal value of n");
         return -2;
     }
     if (k < 0) {
-        cudablas_error(3, "Illegal value of k");
+        gpucublas_error(3, "Illegal value of k");
         return -3;
     }
     if (ib < 0) {
-        cudablas_error(4, "Illegal value of ib");
+        gpucublas_error(4, "Illegal value of ib");
         return -4;
     }
     if (nb < 0) {
-        cudablas_error(5, "Illegal value of nb");
+        gpucublas_error(5, "Illegal value of nb");
         return -5;
     }
     if ( (lda < chameleon_max(1,n)) && (n > 0) ) {
-        cudablas_error(7, "Illegal value of lda");
+        gpucublas_error(7, "Illegal value of lda");
         return -7;
     }
     if ( (ldt < chameleon_max(1,ib)) && (ib > 0) ) {
-        cudablas_error(9, "Illegal value of ldt");
+        gpucublas_error(9, "Illegal value of ldt");
         return -9;
     }
     if ( (ldc < chameleon_max(1,n)) && (n > 0) ) {
-        cudablas_error(11, "Illegal value of ldc");
+        gpucublas_error(11, "Illegal value of ldc");
         return -11;
     }
 
diff --git a/cudablas/compute/cuda_zherk.c b/gpucublas/compute/cuda_zherk.c
similarity index 97%
rename from cudablas/compute/cuda_zherk.c
rename to gpucublas/compute/cuda_zherk.c
index e50cbf0333600f83b81b042669be3388d525420d..b863ce1ac634a3c11f6624c80448550c34f93029 100644
--- a/cudablas/compute/cuda_zherk.c
+++ b/gpucublas/compute/cuda_zherk.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zherk( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zlarfb.c b/gpucublas/compute/cuda_zlarfb.c
similarity index 99%
rename from cudablas/compute/cuda_zlarfb.c
rename to gpucublas/compute/cuda_zlarfb.c
index 8175d1944d74d50ec90f8d59be655c48c3f87942..69da9f1f898320a3527004fe8bd61c94a8b74a75 100644
--- a/cudablas/compute/cuda_zlarfb.c
+++ b/gpucublas/compute/cuda_zlarfb.c
@@ -20,7 +20,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zlarfb( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zlauum.c b/gpucublas/compute/cuda_zlauum.c
similarity index 97%
rename from cudablas/compute/cuda_zlauum.c
rename to gpucublas/compute/cuda_zlauum.c
index ea000c220308b4a6be696640653dc1ac85a50793..305fb345b601c99a97677b9277258a080aabe10d 100644
--- a/cudablas/compute/cuda_zlauum.c
+++ b/gpucublas/compute/cuda_zlauum.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int CUDA_zlauum(
diff --git a/cudablas/compute/cuda_zparfb.c b/gpucublas/compute/cuda_zparfb.c
similarity index 99%
rename from cudablas/compute/cuda_zparfb.c
rename to gpucublas/compute/cuda_zparfb.c
index 8977eb6a169c64e98da17f6c82edc0195733c6c8..778f2511060e46074640200d021e3e2e8ad1ba85 100644
--- a/cudablas/compute/cuda_zparfb.c
+++ b/gpucublas/compute/cuda_zparfb.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 /**
  *
@@ -210,7 +210,7 @@ CUDA_zparfb( cham_side_t side, cham_trans_t trans,
         return wrsize;
     }
     else if ( LWORK < wssize ) {
-        cudablas_error(20, "Illegal value of LWORK");
+        gpucublas_error(20, "Illegal value of LWORK");
         return -20;
     }
 
diff --git a/cudablas/compute/cuda_zpotrf.c b/gpucublas/compute/cuda_zpotrf.c
similarity index 97%
rename from cudablas/compute/cuda_zpotrf.c
rename to gpucublas/compute/cuda_zpotrf.c
index 7c6c86c1456b4fc804fb31732c3e57db454bcc2e..3e51e384d016248c55198a4444d4a36eccc8e7c8 100644
--- a/cudablas/compute/cuda_zpotrf.c
+++ b/gpucublas/compute/cuda_zpotrf.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int CUDA_zpotrf(
diff --git a/cudablas/compute/cuda_zssssm.c b/gpucublas/compute/cuda_zssssm.c
similarity index 98%
rename from cudablas/compute/cuda_zssssm.c
rename to gpucublas/compute/cuda_zssssm.c
index 2bc0d77b89d16a5ff70ebbc913c5421687c37bdb..124e62b8ead8b7d52331c9b0be536042806d50c0 100644
--- a/cudablas/compute/cuda_zssssm.c
+++ b/gpucublas/compute/cuda_zssssm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 #if defined(HAVE_MAGMA_GETRF_INCPIV_GPU)
diff --git a/cudablas/compute/cuda_zsymm.c b/gpucublas/compute/cuda_zsymm.c
similarity index 98%
rename from cudablas/compute/cuda_zsymm.c
rename to gpucublas/compute/cuda_zsymm.c
index b42b86dba2f741f2de8a80751ce12ca54ef7f6d0..6cd5f5baed6464c140e7f7059ee4d4f9afa7480b 100644
--- a/cudablas/compute/cuda_zsymm.c
+++ b/gpucublas/compute/cuda_zsymm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zsymm( cham_side_t side, cham_uplo_t uplo,
diff --git a/cudablas/compute/cuda_zsyr2k.c b/gpucublas/compute/cuda_zsyr2k.c
similarity index 98%
rename from cudablas/compute/cuda_zsyr2k.c
rename to gpucublas/compute/cuda_zsyr2k.c
index 9110eda4cf7424078774c5ecda107e2b0cae2b64..4f280f17158ff7899a1a64bb3668b5ecc497d4f5 100644
--- a/cudablas/compute/cuda_zsyr2k.c
+++ b/gpucublas/compute/cuda_zsyr2k.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zsyr2k( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zsyrk.c b/gpucublas/compute/cuda_zsyrk.c
similarity index 98%
rename from cudablas/compute/cuda_zsyrk.c
rename to gpucublas/compute/cuda_zsyrk.c
index c5d484ecf9ba155fc4ed2b6a5d110063382971cc..4bef5c57e75b92a1aeed7b3de12436c3cc055709 100644
--- a/cudablas/compute/cuda_zsyrk.c
+++ b/gpucublas/compute/cuda_zsyrk.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zsyrk( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_ztpmlqt.c b/gpucublas/compute/cuda_ztpmlqt.c
similarity index 97%
rename from cudablas/compute/cuda_ztpmlqt.c
rename to gpucublas/compute/cuda_ztpmlqt.c
index a46c7ee5ed58a753530cae18874a5eb77df2d878..b41e3f09907dcd9047139c8b40e4612c800d24b3 100644
--- a/cudablas/compute/cuda_ztpmlqt.c
+++ b/gpucublas/compute/cuda_ztpmlqt.c
@@ -17,7 +17,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 /**
  *******************************************************************************
@@ -148,7 +148,7 @@ CUDA_ztpmlqt( cham_side_t side, cham_trans_t trans,
 
     /* Check input arguments */
     if ((side != ChamLeft) && (side != ChamRight)) {
-        cudablas_error(1, "Illegal value of side");
+        gpucublas_error(1, "Illegal value of side");
         return -1;
     }
 
@@ -176,7 +176,7 @@ CUDA_ztpmlqt( cham_side_t side, cham_trans_t trans,
                      handle );
     }
     else {
-        cudablas_error(-6, "TPMLQT not available on GPU for general cases yet\n" );
+        gpucublas_error(-6, "TPMLQT not available on GPU for general cases yet\n" );
         return -6;
     }
 
diff --git a/cudablas/compute/cuda_ztpmqrt.c b/gpucublas/compute/cuda_ztpmqrt.c
similarity index 97%
rename from cudablas/compute/cuda_ztpmqrt.c
rename to gpucublas/compute/cuda_ztpmqrt.c
index a44b6fb27d592bf63d5a387e27a98a00f982e951..3087a8bb0196685f5b560d1a6da86a016d4ca969 100644
--- a/cudablas/compute/cuda_ztpmqrt.c
+++ b/gpucublas/compute/cuda_ztpmqrt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 /**
  *******************************************************************************
@@ -150,7 +150,7 @@ CUDA_ztpmqrt( cham_side_t side, cham_trans_t trans,
 
     /* Check input arguments */
     if ((side != ChamLeft) && (side != ChamRight)) {
-        cudablas_error(1, "Illegal value of side");
+        gpucublas_error(1, "Illegal value of side");
         return -1;
     }
 
@@ -178,7 +178,7 @@ CUDA_ztpmqrt( cham_side_t side, cham_trans_t trans,
                      handle );
     }
     else {
-        cudablas_error(-6, "TPMQRT not available on GPU for general cases yet\n" );
+        gpucublas_error(-6, "TPMQRT not available on GPU for general cases yet\n" );
         return -6;
     }
 
diff --git a/cudablas/compute/cuda_ztrmm.c b/gpucublas/compute/cuda_ztrmm.c
similarity index 98%
rename from cudablas/compute/cuda_ztrmm.c
rename to gpucublas/compute/cuda_ztrmm.c
index ead07f97d154d05499800272e3c9c1043d799000..ceaceca15d9a0199d447f54b870f24b0654f63ab 100644
--- a/cudablas/compute/cuda_ztrmm.c
+++ b/gpucublas/compute/cuda_ztrmm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_ztrmm( cham_side_t side, cham_uplo_t uplo,
diff --git a/cudablas/compute/cuda_ztrsm.c b/gpucublas/compute/cuda_ztrsm.c
similarity index 98%
rename from cudablas/compute/cuda_ztrsm.c
rename to gpucublas/compute/cuda_ztrsm.c
index 23e8c0ee6ec9b50c2af0489d251cdf1ef73cc6d4..d4591d07b205c3178a0a4000283f09b23c0454a0 100644
--- a/cudablas/compute/cuda_ztrsm.c
+++ b/gpucublas/compute/cuda_ztrsm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_ztrsm( cham_side_t side, cham_uplo_t uplo,
diff --git a/cudablas/compute/cuda_ztrtri.c b/gpucublas/compute/cuda_ztrtri.c
similarity index 97%
rename from cudablas/compute/cuda_ztrtri.c
rename to gpucublas/compute/cuda_ztrtri.c
index d79310acccff84f03482838ab531587302e1e884..927540248b57c453e1b199327e033f0f8ca14de9 100644
--- a/cudablas/compute/cuda_ztrtri.c
+++ b/gpucublas/compute/cuda_ztrtri.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int CUDA_ztrtri(
diff --git a/cudablas/compute/cuda_ztslqt.c b/gpucublas/compute/cuda_ztslqt.c
similarity index 99%
rename from cudablas/compute/cuda_ztslqt.c
rename to gpucublas/compute/cuda_ztslqt.c
index 174941232b7fed379210881062e31c6ea88d5bc7..1a238e91b6d37a24b0aec9f30c63fcabd87338c1 100644
--- a/cudablas/compute/cuda_ztslqt.c
+++ b/gpucublas/compute/cuda_ztslqt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA) && 0
 int CUDA_ztslqt(
diff --git a/cudablas/compute/cuda_ztsmlq.c b/gpucublas/compute/cuda_ztsmlq.c
similarity index 99%
rename from cudablas/compute/cuda_ztsmlq.c
rename to gpucublas/compute/cuda_ztsmlq.c
index f75dfa8015a35cef56465a324c7d5260201f9b37..10c5d628346d30f69f59da3926f90b1ae81466bb 100644
--- a/cudablas/compute/cuda_ztsmlq.c
+++ b/gpucublas/compute/cuda_ztsmlq.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_ztsmlq( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_ztsmqr.c b/gpucublas/compute/cuda_ztsmqr.c
similarity index 99%
rename from cudablas/compute/cuda_ztsmqr.c
rename to gpucublas/compute/cuda_ztsmqr.c
index ff5c9fef0a39cacff543b71b9ce15ca14fbe0d41..471ada70e31c897a11140bb08be41f84403efea1 100644
--- a/cudablas/compute/cuda_ztsmqr.c
+++ b/gpucublas/compute/cuda_ztsmqr.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_ztsmqr( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_ztsqrt.c b/gpucublas/compute/cuda_ztsqrt.c
similarity index 99%
rename from cudablas/compute/cuda_ztsqrt.c
rename to gpucublas/compute/cuda_ztsqrt.c
index 90bd21d8610ad858eb36e5dd7b7c254cab3f094b..2add23cd6688aeb7bcc7bfc1d3f887dd37a69699 100644
--- a/cudablas/compute/cuda_ztsqrt.c
+++ b/gpucublas/compute/cuda_ztsqrt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA)
 int CUDA_ztsqrt(
diff --git a/cudablas/compute/cuda_ztstrf.c b/gpucublas/compute/cuda_ztstrf.c
similarity index 98%
rename from cudablas/compute/cuda_ztstrf.c
rename to gpucublas/compute/cuda_ztstrf.c
index df836c4285d0750acb94a79805eceda61949a11c..bcf35a138c2ff658da1be9f83df2231d60b6478f 100644
--- a/cudablas/compute/cuda_ztstrf.c
+++ b/gpucublas/compute/cuda_ztstrf.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 #if defined(CHAMELEON_USE_MAGMA) && 0
 int CUDA_ztstrf(
diff --git a/cudablas/compute/cuda_zttmlq.c b/gpucublas/compute/cuda_zttmlq.c
similarity index 99%
rename from cudablas/compute/cuda_zttmlq.c
rename to gpucublas/compute/cuda_zttmlq.c
index 131f6c3536a51b54e5c500cbfb5e1b99276a95a9..6b5c5738a2a7a887a0cd2b69754c15392eaf13af 100644
--- a/cudablas/compute/cuda_zttmlq.c
+++ b/gpucublas/compute/cuda_zttmlq.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zttmlq( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zttmqr.c b/gpucublas/compute/cuda_zttmqr.c
similarity index 99%
rename from cudablas/compute/cuda_zttmqr.c
rename to gpucublas/compute/cuda_zttmqr.c
index a9078ba09d761efdaff21322113ca9acdb4d79ac..68ab000e9c37355cdd69b265cb16701670c34e53 100644
--- a/cudablas/compute/cuda_zttmqr.c
+++ b/gpucublas/compute/cuda_zttmqr.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zttmqr( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zunmlqt.c b/gpucublas/compute/cuda_zunmlqt.c
similarity index 99%
rename from cudablas/compute/cuda_zunmlqt.c
rename to gpucublas/compute/cuda_zunmlqt.c
index 24db8582833f02822ce0fa2192080e546af01975..918fb3f1d19d4f6f36deeee054dc342c4efe2d31 100644
--- a/cudablas/compute/cuda_zunmlqt.c
+++ b/gpucublas/compute/cuda_zunmlqt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zunmlqt( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cuda_zunmqrt.c b/gpucublas/compute/cuda_zunmqrt.c
similarity index 99%
rename from cudablas/compute/cuda_zunmqrt.c
rename to gpucublas/compute/cuda_zunmqrt.c
index 01f5f14bba00891d028a9d71405f292bba221e66..f6e4e2dd70641d3f3b299abbcf63881179511e5c 100644
--- a/cudablas/compute/cuda_zunmqrt.c
+++ b/gpucublas/compute/cuda_zunmqrt.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 int
 CUDA_zunmqrt( cham_side_t side, cham_trans_t trans,
diff --git a/cudablas/compute/cudaglobal.c b/gpucublas/compute/cudaglobal.c
similarity index 98%
rename from cudablas/compute/cudaglobal.c
rename to gpucublas/compute/cudaglobal.c
index cbcbf5b2fca1e52136865a502cc4e3f74af80838..bc0cf74a104617ff2fe1ebfda76b50a80c5cf7b0 100644
--- a/cudablas/compute/cudaglobal.c
+++ b/gpucublas/compute/cudaglobal.c
@@ -9,7 +9,7 @@
  *
  ***
  *
- * @brief Chameleon global cudablas variables and functions
+ * @brief Chameleon global gpucublas variables and functions
  *
  * @version 1.2.0
  * @author Mathieu Faverge
@@ -17,7 +17,7 @@
  * @date 2022-02-22
  *
  */
-#include "cudablas.h"
+#include "gpucublas.h"
 
 /**
  *  LAPACK Constants
diff --git a/cudablas/eztrace_module/CMakeLists.txt b/gpucublas/eztrace_module/CMakeLists.txt
similarity index 94%
rename from cudablas/eztrace_module/CMakeLists.txt
rename to gpucublas/eztrace_module/CMakeLists.txt
index 8a298a86845d2f23278bd7c7319c8c9f6715837a..83e737220bd6e93c8095d12a6b2df021387b404f 100644
--- a/cudablas/eztrace_module/CMakeLists.txt
+++ b/gpucublas/eztrace_module/CMakeLists.txt
@@ -43,8 +43,8 @@ if (EZTRACE_FOUND AND EZTRACE_DIR_FOUND)
         add_custom_command(
             OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/output
             COMMAND ${EZTRACE_CREATE_PLUGIN}
-            ARGS ${CMAKE_CURRENT_SOURCE_DIR}/cudablas_eztrace_module
-            DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/cudablas_eztrace_module
+            ARGS ${CMAKE_CURRENT_SOURCE_DIR}/gpucublas_eztrace_module
+            DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/gpucublas_eztrace_module
             )
         add_custom_target(
             eztrace-module-chameleon_cuda-dir ALL
diff --git a/cudablas/eztrace_module/cudablas_eztrace_module b/gpucublas/eztrace_module/gpucublas_eztrace_module
similarity index 100%
rename from cudablas/eztrace_module/cudablas_eztrace_module
rename to gpucublas/eztrace_module/gpucublas_eztrace_module
diff --git a/cudablas/include/CMakeLists.txt b/gpucublas/include/CMakeLists.txt
similarity index 65%
rename from cudablas/include/CMakeLists.txt
rename to gpucublas/include/CMakeLists.txt
index 12dbc469270f59288ba1ef0860953bc6b0583284..b208d377e5b85e2549153728182caa53c9ffa2ef 100644
--- a/cudablas/include/CMakeLists.txt
+++ b/gpucublas/include/CMakeLists.txt
@@ -26,39 +26,39 @@
 
 # Generate header files
 # ---------------------
-set(CUDABLAS_HDRS_GENERATED "")
+set(GPUCUBLAS_HDRS_GENERATED "")
 set(ZHDR
-    cudablas/cudablas_z.h
+    gpucublas/gpucublas_z.h
 )
 precisions_rules_py(
-  CUDABLAS_HDRS_GENERATED "${ZHDR}"
-  TARGETDIR cudablas
+  GPUCUBLAS_HDRS_GENERATED "${ZHDR}"
+  TARGETDIR gpucublas
   PRECISIONS "s;d;c;z;zc;ds" )
 
 # Define the list of headers
 # --------------------------
-set(CUDABLAS_HDRS
-    cudablas.h
+set(GPUCUBLAS_HDRS
+    gpucublas.h
     )
 
 # Add generated headers
 # ---------------------
-foreach( hdr_file ${CUDABLAS_HDRS_GENERATED} )
-  list(APPEND CUDABLAS_HDRS ${CMAKE_CURRENT_BINARY_DIR}/${hdr_file})
+foreach( hdr_file ${GPUCUBLAS_HDRS_GENERATED} )
+  list(APPEND GPUCUBLAS_HDRS ${CMAKE_CURRENT_BINARY_DIR}/${hdr_file})
 endforeach()
 
 # Force generation of headers
 # ---------------------------
-add_custom_target(cudablas_include ALL SOURCES ${CUDABLAS_HDRS})
-set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};cudablas_include" CACHE INTERNAL "List of targets of sources")
+add_custom_target(gpucublas_include ALL SOURCES ${GPUCUBLAS_HDRS})
+set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};gpucublas_include" CACHE INTERNAL "List of targets of sources")
 
 # Installation
 # ------------
-install( FILES cudablas.h
+install( FILES gpucublas.h
          DESTINATION include )
 
-install( FILES ${CUDABLAS_HDRS}
-         DESTINATION include/cudablas )
+install( FILES ${GPUCUBLAS_HDRS}
+         DESTINATION include/gpucublas )
 
 ###
 ### END CMakeLists.txt
diff --git a/cudablas/include/cudablas.h b/gpucublas/include/gpucublas.h
similarity index 81%
rename from cudablas/include/cudablas.h
rename to gpucublas/include/gpucublas.h
index fc6fe7a713e22de8a968678fb2311d69909f23fb..90f05f44b1feef38ad0b2088257e1738f7e6b727 100644
--- a/cudablas/include/cudablas.h
+++ b/gpucublas/include/gpucublas.h
@@ -1,6 +1,6 @@
 /**
  *
- * @file cudablas.h
+ * @file gpucublas.h
  *
  * @copyright 2009-2014 The University of Tennessee and The University of
  *                      Tennessee Research Foundation. All rights reserved.
@@ -19,8 +19,8 @@
  * @precisions normal z -> c d s
  *
  */
-#ifndef _cudablas_h_
-#define _cudablas_h_
+#ifndef _gpucublas_h_
+#define _gpucublas_h_
 
 #include "chameleon/config.h"
 
@@ -54,17 +54,17 @@
  */
 BEGIN_C_DECLS
 
-#include "cudablas/cudablas_z.h"
-#include "cudablas/cudablas_d.h"
-#include "cudablas/cudablas_c.h"
-#include "cudablas/cudablas_s.h"
+#include "gpucublas/gpucublas_z.h"
+#include "gpucublas/gpucublas_d.h"
+#include "gpucublas/gpucublas_c.h"
+#include "gpucublas/gpucublas_s.h"
 
 END_C_DECLS
 
 /**
  * Coreblas Error
  */
-#define cudablas_error(k, str) fprintf(stderr, "%s: Parameter %d / %s\n", __func__, k, str)
+#define gpucublas_error(k, str) fprintf(stderr, "%s: Parameter %d / %s\n", __func__, k, str)
 
 /**
  *  LAPACK Constants
@@ -79,4 +79,4 @@ extern int chameleon_cublas_constants[];
 
 END_C_DECLS
 
-#endif /* _cudablas_h_ */
+#endif /* _gpucublas_h_ */
diff --git a/cudablas/include/cudablas/cudablas_z.h b/gpucublas/include/gpucublas/gpucublas_z.h
similarity index 98%
rename from cudablas/include/cudablas/cudablas_z.h
rename to gpucublas/include/gpucublas/gpucublas_z.h
index d0fa9be789de00afe44ae5c53172ace18ccac4ce..0773e003598a9a72597355dc71d5f785ec48af70 100644
--- a/cudablas/include/cudablas/cudablas_z.h
+++ b/gpucublas/include/gpucublas/gpucublas_z.h
@@ -1,6 +1,6 @@
 /**
  *
- * @file cudablas_z.h
+ * @file gpucublas_z.h
  *
  * @copyright 2009-2014 The University of Tennessee and The University of
  *                      Tennessee Research Foundation. All rights reserved.
@@ -18,8 +18,8 @@
  * @precisions normal z -> c d s
  *
  */
-#ifndef _cudablas_z_h_
-#define _cudablas_z_h_
+#ifndef _gpucublas_z_h_
+#define _gpucublas_z_h_
 
 /**
  *  Declarations of cuda kernels - alphabetical order
@@ -47,4 +47,4 @@ int CUDA_zttmqr( cham_side_t side, cham_trans_t trans, int M1, int N1, int M2, i
 int CUDA_zunmlqt(cham_side_t side, cham_trans_t trans, int M, int N, int K, int IB, const cuDoubleComplex *A,    int LDA, const cuDoubleComplex *T,    int LDT, cuDoubleComplex *C,    int LDC, cuDoubleComplex *WORK, int LDWORK, cublasHandle_t handle );
 int CUDA_zunmqrt(cham_side_t side, cham_trans_t trans, int M, int N, int K, int IB, const cuDoubleComplex *A,    int LDA, const cuDoubleComplex *T,    int LDT, cuDoubleComplex *C,    int LDC, cuDoubleComplex *WORK, int LDWORK, cublasHandle_t handle );
 
-#endif /* _cudablas_z_h_ */
+#endif /* _gpucublas_z_h_ */
diff --git a/hipblas/CMakeLists.txt b/gpuhipblas/CMakeLists.txt
similarity index 100%
rename from hipblas/CMakeLists.txt
rename to gpuhipblas/CMakeLists.txt
diff --git a/hipblas/compute/CMakeLists.txt b/gpuhipblas/compute/CMakeLists.txt
similarity index 59%
rename from hipblas/compute/CMakeLists.txt
rename to gpuhipblas/compute/CMakeLists.txt
index 632049557a2206d22f83e7432268dd39f42ed303..bd7ac4540ccad44d08140014a6af1af43df248b5 100644
--- a/hipblas/compute/CMakeLists.txt
+++ b/gpuhipblas/compute/CMakeLists.txt
@@ -28,7 +28,7 @@
 
 # Generate the chameleon sources for all possible precisions
 # ------------------------------------------------------
-set(HIPBLAS_SRCS_GENERATED "")
+set(GPUHIPBLAS_SRCS_GENERATED "")
 set(ZSRC
     hip_zgemm.c
     hip_zhemm.c
@@ -42,46 +42,46 @@ set(ZSRC
     )
 
 precisions_rules_py(
-  HIPBLAS_SRCS_GENERATED "${ZSRC}"
+  GPUHIPBLAS_SRCS_GENERATED "${ZSRC}"
   PRECISIONS "${CHAMELEON_PRECISION}")
 
-set(HIPBLAS_SRCS
-  ${HIPBLAS_SRCS_GENERATED}
+set(GPUHIPBLAS_SRCS
+  ${GPUHIPBLAS_SRCS_GENERATED}
   hipglobal.c
   )
 
 # Force generation of sources
 # ---------------------------
-add_custom_target(hipblas_sources ALL SOURCES ${HIPBLAS_SRCS})
-set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};hipblas_sources" CACHE INTERNAL "List of targets of sources")
+add_custom_target(gpuhipblas_sources ALL SOURCES ${GPUHIPBLAS_SRCS})
+set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};gpuhipblas_sources" CACHE INTERNAL "List of targets of sources")
 
 # Compile step
 # ------------
-add_library(hipblas ${HIPBLAS_SRCS})
-set_target_properties(hipblas PROPERTIES VERSION ${CHAMELEON_VERSION})
-set_target_properties(hipblas PROPERTIES SOVERSION ${CHAMELEON_VERSION_MAJOR})
-add_dependencies(hipblas hipblas_include hipblas_sources)
-target_include_directories(hipblas PUBLIC
-  $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/hipblas/include>
-  $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/hipblas/include>
+add_library(gpuhipblas ${GPUHIPBLAS_SRCS})
+set_target_properties(gpuhipblas PROPERTIES VERSION ${CHAMELEON_VERSION})
+set_target_properties(gpuhipblas PROPERTIES SOVERSION ${CHAMELEON_VERSION_MAJOR})
+add_dependencies(gpuhipblas gpuhipblas_include gpuhipblas_sources)
+target_include_directories(gpuhipblas PUBLIC
+  $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/gpuhipblas/include>
+  $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/gpuhipblas/include>
   $<BUILD_INTERFACE:${CHAMELEON_SOURCE_DIR}/include>
   $<BUILD_INTERFACE:${CHAMELEON_BINARY_DIR}/include>
   $<INSTALL_INTERFACE:include>)
-set_property(TARGET hipblas PROPERTY INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib")
+set_property(TARGET gpuhipblas PROPERTY INSTALL_NAME_DIR "${CMAKE_INSTALL_PREFIX}/lib")
 
-target_link_libraries(hipblas PRIVATE coreblas HIP::HIPBLAS)
-target_link_libraries(hipblas PUBLIC MORSE::M)
+target_link_libraries(gpuhipblas PRIVATE coreblas HIP::HIPBLAS)
+target_link_libraries(gpuhipblas PUBLIC MORSE::M)
 
 # export target coreblas
-install(EXPORT hipblasTargets
+install(EXPORT gpuhipblasTargets
         NAMESPACE CHAMELEON::
         DESTINATION lib/cmake/chameleon
         )
 
 # installation
 # ------------
-install(TARGETS hipblas
-        EXPORT hipblasTargets
+install(TARGETS gpuhipblas
+        EXPORT gpuhipblasTargets
         ARCHIVE DESTINATION lib
         LIBRARY DESTINATION lib
         )
diff --git a/hipblas/compute/hip_zgemm.c b/gpuhipblas/compute/hip_zgemm.c
similarity index 98%
rename from hipblas/compute/hip_zgemm.c
rename to gpuhipblas/compute/hip_zgemm.c
index ed42fa7b8cde3133edcc82bc06c590c9311f011a..0fe90f606c06b663cf240d144546c0a0c2595222 100644
--- a/hipblas/compute/hip_zgemm.c
+++ b/gpuhipblas/compute/hip_zgemm.c
@@ -19,7 +19,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zgemm( cham_trans_t transa, cham_trans_t transb,
diff --git a/hipblas/compute/hip_zhemm.c b/gpuhipblas/compute/hip_zhemm.c
similarity index 98%
rename from hipblas/compute/hip_zhemm.c
rename to gpuhipblas/compute/hip_zhemm.c
index 1d69367839189685c80681f1ae25698cae1b6ab1..f1724738ee46612a41bd19e2a1be5f6bcb0fe7c0 100644
--- a/hipblas/compute/hip_zhemm.c
+++ b/gpuhipblas/compute/hip_zhemm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zhemm( cham_side_t side, cham_uplo_t uplo,
diff --git a/hipblas/compute/hip_zher2k.c b/gpuhipblas/compute/hip_zher2k.c
similarity index 98%
rename from hipblas/compute/hip_zher2k.c
rename to gpuhipblas/compute/hip_zher2k.c
index fc245eb3e62d9fb91fa9f4b1a11c3f71490e1890..f6bf36023c275b26ad094405ade80cc144a16738 100644
--- a/hipblas/compute/hip_zher2k.c
+++ b/gpuhipblas/compute/hip_zher2k.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zher2k( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/hipblas/compute/hip_zherk.c b/gpuhipblas/compute/hip_zherk.c
similarity index 97%
rename from hipblas/compute/hip_zherk.c
rename to gpuhipblas/compute/hip_zherk.c
index c31247546e40e6e470b2f9422ecdd9119a6ce37e..ce0005812c4ec6610476c8e803fa9e3eb83cf95c 100644
--- a/hipblas/compute/hip_zherk.c
+++ b/gpuhipblas/compute/hip_zherk.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zherk( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/hipblas/compute/hip_zsymm.c b/gpuhipblas/compute/hip_zsymm.c
similarity index 98%
rename from hipblas/compute/hip_zsymm.c
rename to gpuhipblas/compute/hip_zsymm.c
index 3c25f9073f2d543a3572df89d9deec0f50edf76a..f217c27ddb0349bf8f7b0208dcae96a931ded90c 100644
--- a/hipblas/compute/hip_zsymm.c
+++ b/gpuhipblas/compute/hip_zsymm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zsymm( cham_side_t side, cham_uplo_t uplo,
diff --git a/hipblas/compute/hip_zsyr2k.c b/gpuhipblas/compute/hip_zsyr2k.c
similarity index 98%
rename from hipblas/compute/hip_zsyr2k.c
rename to gpuhipblas/compute/hip_zsyr2k.c
index 6da295381217246465b2a3b3d4b26c24b5e2b006..3f3197b2fbf01fb9046e26ac5c62140c4ba9e29f 100644
--- a/hipblas/compute/hip_zsyr2k.c
+++ b/gpuhipblas/compute/hip_zsyr2k.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zsyr2k( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/hipblas/compute/hip_zsyrk.c b/gpuhipblas/compute/hip_zsyrk.c
similarity index 97%
rename from hipblas/compute/hip_zsyrk.c
rename to gpuhipblas/compute/hip_zsyrk.c
index 63b87ac14558abf6887f87a709aa8af6f36663ef..2d6dac816a06095affae498812af3373f823b6ab 100644
--- a/hipblas/compute/hip_zsyrk.c
+++ b/gpuhipblas/compute/hip_zsyrk.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_zsyrk( cham_uplo_t uplo, cham_trans_t trans,
diff --git a/hipblas/compute/hip_ztrmm.c b/gpuhipblas/compute/hip_ztrmm.c
similarity index 98%
rename from hipblas/compute/hip_ztrmm.c
rename to gpuhipblas/compute/hip_ztrmm.c
index f281385ab1e26c66f7579cb5172d4eb9afdc02b2..73141dcfd674a16ae97ca961f844370889900a91 100644
--- a/hipblas/compute/hip_ztrmm.c
+++ b/gpuhipblas/compute/hip_ztrmm.c
@@ -18,7 +18,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_ztrmm( cham_side_t side, cham_uplo_t uplo,
diff --git a/hipblas/compute/hip_ztrsm.c b/gpuhipblas/compute/hip_ztrsm.c
similarity index 98%
rename from hipblas/compute/hip_ztrsm.c
rename to gpuhipblas/compute/hip_ztrsm.c
index d2d939e837c6578bdbc2acb159b426b1ef8d3b0b..7c0c44124c04f58b6da9d0319a32be291a0ab833 100644
--- a/hipblas/compute/hip_ztrsm.c
+++ b/gpuhipblas/compute/hip_ztrsm.c
@@ -19,7 +19,7 @@
  * @precisions normal z -> c d s
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 int
 HIP_ztrsm( cham_side_t side, cham_uplo_t uplo,
diff --git a/hipblas/compute/hipglobal.c b/gpuhipblas/compute/hipglobal.c
similarity index 99%
rename from hipblas/compute/hipglobal.c
rename to gpuhipblas/compute/hipglobal.c
index 3c9fce60274ea6d317354cea67b7396e7fc5f65e..2da05eac2c26e25520efb8b0c89a91d76412a238 100644
--- a/hipblas/compute/hipglobal.c
+++ b/gpuhipblas/compute/hipglobal.c
@@ -17,7 +17,7 @@
  * @date 2023-01-30
  *
  */
-#include "hipblas.h"
+#include "gpuhipblas.h"
 
 /**
  *  LAPACK Constants
diff --git a/hipblas/eztrace_module/CMakeLists.txt b/gpuhipblas/eztrace_module/CMakeLists.txt
similarity index 94%
rename from hipblas/eztrace_module/CMakeLists.txt
rename to gpuhipblas/eztrace_module/CMakeLists.txt
index f46c2e28d69199403a00cb16d60a2497ff9db207..444a6d3de453925ab073751d13160276809239c2 100644
--- a/hipblas/eztrace_module/CMakeLists.txt
+++ b/gpuhipblas/eztrace_module/CMakeLists.txt
@@ -43,8 +43,8 @@ if (EZTRACE_FOUND AND EZTRACE_DIR_FOUND)
         add_custom_command(
             OUTPUT ${CMAKE_CURRENT_BINARY_DIR}/output
             COMMAND ${EZTRACE_CREATE_PLUGIN}
-            ARGS ${CMAKE_CURRENT_SOURCE_DIR}/hipblas_eztrace_module
-            DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/hipblas_eztrace_module
+            ARGS ${CMAKE_CURRENT_SOURCE_DIR}/gpuhipblas_eztrace_module
+            DEPENDS ${CMAKE_CURRENT_SOURCE_DIR}/gpuhipblas_eztrace_module
             )
         add_custom_target(
             eztrace-module-chameleon_hip-dir ALL
diff --git a/hipblas/eztrace_module/hipblas_eztrace_module b/gpuhipblas/eztrace_module/gpuhipblas_eztrace_module
similarity index 100%
rename from hipblas/eztrace_module/hipblas_eztrace_module
rename to gpuhipblas/eztrace_module/gpuhipblas_eztrace_module
diff --git a/hipblas/include/CMakeLists.txt b/gpuhipblas/include/CMakeLists.txt
similarity index 65%
rename from hipblas/include/CMakeLists.txt
rename to gpuhipblas/include/CMakeLists.txt
index ec1b8e3b459333670f40b5c2389a37e6c435f1fb..16aa695481e3a6284844e5833122867c2789848b 100644
--- a/hipblas/include/CMakeLists.txt
+++ b/gpuhipblas/include/CMakeLists.txt
@@ -27,39 +27,39 @@
 
 # Generate header files
 # ---------------------
-set(HIPBLAS_HDRS_GENERATED "")
+set(GPUHIPBLAS_HDRS_GENERATED "")
 set(ZHDR
-    hipblas/hipblas_z.h
+    gpuhipblas/gpuhipblas_z.h
 )
 precisions_rules_py(
-  HIPBLAS_HDRS_GENERATED "${ZHDR}"
-  TARGETDIR hipblas
+  GPUHIPBLAS_HDRS_GENERATED "${ZHDR}"
+  TARGETDIR gpuhipblas
   PRECISIONS "s;d;c;z;zc;ds" )
 
 # Define the list of headers
 # --------------------------
-set(HIPBLAS_HDRS
-    hipblas.h
+set(GPUHIPBLAS_HDRS
+    gpuhipblas.h
     )
 
 # Add generated headers
 # ---------------------
-foreach( hdr_file ${HIPBLAS_HDRS_GENERATED} )
-  list(APPEND HIPBLAS_HDRS ${CMAKE_CURRENT_BINARY_DIR}/${hdr_file})
+foreach( hdr_file ${GPUHIPBLAS_HDRS_GENERATED} )
+  list(APPEND GPUHIPBLAS_HDRS ${CMAKE_CURRENT_BINARY_DIR}/${hdr_file})
 endforeach()
 
 # Force generation of headers
 # ---------------------------
-add_custom_target(hipblas_include ALL SOURCES ${HIPBLAS_HDRS})
-set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};hipblas_include" CACHE INTERNAL "List of targets of sources")
+add_custom_target(gpuhipblas_include ALL SOURCES ${GPUHIPBLAS_HDRS})
+set(CHAMELEON_SOURCES_TARGETS "${CHAMELEON_SOURCES_TARGETS};gpuhipblas_include" CACHE INTERNAL "List of targets of sources")
 
 # Installation
 # ------------
-install( FILES hipblas.h
+install( FILES gpuhipblas.h
          DESTINATION include )
 
-install( FILES ${HIPBLAS_HDRS}
-         DESTINATION include/hipblas )
+install( FILES ${GPUHIPBLAS_HDRS}
+         DESTINATION include/gpuhipblas )
 
 ###
 ### END CMakeLists.txt
diff --git a/hipblas/include/hipblas.h b/gpuhipblas/include/gpuhipblas.h
similarity index 80%
rename from hipblas/include/hipblas.h
rename to gpuhipblas/include/gpuhipblas.h
index 333bbc2d91801f05404d0655ec6e15848edf849f..572abcf9677fa3caf1e16f8c6a68a64f6e202cb9 100644
--- a/hipblas/include/hipblas.h
+++ b/gpuhipblas/include/gpuhipblas.h
@@ -1,6 +1,6 @@
 /**
  *
- * @file hipblas.h
+ * @file gpuhipblas.h
  *
  * @copyright 2009-2014 The University of Tennessee and The University of
  *                      Tennessee Research Foundation. All rights reserved.
@@ -20,8 +20,8 @@
  * @precisions normal z -> c d s
  *
  */
-#ifndef _hipblas_h_
-#define _hipblas_h_
+#ifndef _gpuhipblas_h_
+#define _gpuhipblas_h_
 
 #include "chameleon/config.h"
 
@@ -54,17 +54,17 @@
  */
 BEGIN_C_DECLS
 
-#include "hipblas/hipblas_z.h"
-#include "hipblas/hipblas_d.h"
-#include "hipblas/hipblas_c.h"
-#include "hipblas/hipblas_s.h"
+#include "gpuhipblas/gpuhipblas_z.h"
+#include "gpuhipblas/gpuhipblas_d.h"
+#include "gpuhipblas/gpuhipblas_c.h"
+#include "gpuhipblas/gpuhipblas_s.h"
 
 END_C_DECLS
 
 /**
  * Coreblas Error
  */
-#define hipblas_error(k, str) fprintf(stderr, "%s: Parameter %d / %s\n", __func__, k, str)
+#define gpuhipblas_error(k, str) fprintf(stderr, "%s: Parameter %d / %s\n", __func__, k, str)
 
 /**
  *  LAPACK Constants
@@ -79,4 +79,4 @@ extern int chameleon_hipblas_constants[];
 
 END_C_DECLS
 
-#endif /* _hipblas_h_ */
+#endif /* _gpuhipblas_h_ */
diff --git a/hipblas/include/hipblas/hipblas_z.h b/gpuhipblas/include/gpuhipblas/gpuhipblas_z.h
similarity index 96%
rename from hipblas/include/hipblas/hipblas_z.h
rename to gpuhipblas/include/gpuhipblas/gpuhipblas_z.h
index 3e4509a3c17d8912ceee284c04b35e676be56a2a..0b6f8837a3d7f0d39ace339f6a5db2df483947e6 100644
--- a/hipblas/include/hipblas/hipblas_z.h
+++ b/gpuhipblas/include/gpuhipblas/gpuhipblas_z.h
@@ -1,6 +1,6 @@
 /**
  *
- * @file hipblas_z.h
+ * @file gpuhipblas_z.h
  *
  * @copyright 2009-2014 The University of Tennessee and The University of
  *                      Tennessee Research Foundation. All rights reserved.
@@ -19,8 +19,8 @@
  * @precisions normal z -> c d s
  *
  */
-#ifndef _hipblas_z_h_
-#define _hipblas_z_h_
+#ifndef _gpuhipblas_z_h_
+#define _gpuhipblas_z_h_
 
 /**
  *  Declarations of hip kernels - alphabetical order
@@ -35,4 +35,4 @@ int HIP_zsyrk(  cham_uplo_t uplo, cham_trans_t trans, int n, int k, const hipbla
 int HIP_ztrmm(  cham_side_t side, cham_uplo_t uplo, cham_trans_t transa, cham_diag_t diag, int m, int n, const hipblasDoubleComplex *alpha, const hipblasDoubleComplex *A, int lda, hipblasDoubleComplex *B, int ldb, hipblasHandle_t handle );
 int HIP_ztrsm(  cham_side_t side, cham_uplo_t uplo, cham_trans_t transa, cham_diag_t diag, int m, int n, const hipblasDoubleComplex *alpha, const hipblasDoubleComplex *A, int lda, hipblasDoubleComplex *B, int ldb, hipblasHandle_t handle );
 
-#endif /* _hipblas_z_h_ */
+#endif /* _gpuhipblas_z_h_ */
diff --git a/lib/pkgconfig/cudablas.pc.in b/lib/pkgconfig/gpucublas.pc.in
similarity index 62%
rename from lib/pkgconfig/cudablas.pc.in
rename to lib/pkgconfig/gpucublas.pc.in
index c9d38dfde8fefcc8737c66ecf2bc2bfba14d3cb2..0aef0c0b2d30e963a294bf5428129c22d86fab5f 100644
--- a/lib/pkgconfig/cudablas.pc.in
+++ b/lib/pkgconfig/gpucublas.pc.in
@@ -1,5 +1,5 @@
 #
-#  @file cudablas.pc
+#  @file gpucublas.pc
 #
 #  @copyright 2016-2023 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 #                       Univ. Bordeaux. All rights reserved.
@@ -13,11 +13,11 @@ exec_prefix=${prefix}
 libdir=${exec_prefix}/lib
 includedir=${exec_prefix}/include
 
-Name: cudablas
+Name: gpucublas
 Description: Interface to cuBLAS routines + some other auxiliary routines
 Version: @CHAMELEON_VERSION_MAJOR@.@CHAMELEON_VERSION_MINOR@.@CHAMELEON_VERSION_MICRO@
-Cflags: @CUDABLAS_PKGCONFIG_DEFINITIONS@ -I${includedir}
-Libs: -L${libdir} @CUDABLAS_PKGCONFIG_LIBS@
-Libs.private: @CUDABLAS_PKGCONFIG_LIBS_PRIVATE@
-Requires: @CUDABLAS_PKGCONFIG_REQUIRED@
-Requires.private: @CUDABLAS_PKGCONFIG_REQUIRED_PRIVATE@
+Cflags: @GPUCUBLAS_PKGCONFIG_DEFINITIONS@ -I${includedir}
+Libs: -L${libdir} @GPUCUBLAS_PKGCONFIG_LIBS@
+Libs.private: @GPUCUBLAS_PKGCONFIG_LIBS_PRIVATE@
+Requires: @GPUCUBLAS_PKGCONFIG_REQUIRED@
+Requires.private: @GPUCUBLAS_PKGCONFIG_REQUIRED_PRIVATE@
diff --git a/lib/pkgconfig/hipblas.pc.in b/lib/pkgconfig/gpuhipblas.pc.in
similarity index 61%
rename from lib/pkgconfig/hipblas.pc.in
rename to lib/pkgconfig/gpuhipblas.pc.in
index 78d0f55d493774f3c7ef0b712073d41ff126f241..08c80fe3d4407c8270a0bdc8c14754cb0f328317 100644
--- a/lib/pkgconfig/hipblas.pc.in
+++ b/lib/pkgconfig/gpuhipblas.pc.in
@@ -1,5 +1,5 @@
 #
-#  @file hipblas.pc
+#  @file gpuhipblas.pc
 #
 #  @copyright 2016-2023 Bordeaux INP, CNRS (LaBRI UMR 5800), Inria,
 #                       Univ. Bordeaux. All rights reserved.
@@ -13,11 +13,11 @@ exec_prefix=${prefix}
 libdir=${exec_prefix}/lib
 includedir=${exec_prefix}/include
 
-Name: hipblas
+Name: gpuhipblas
 Description: Interface to hipBLAS routines + some other auxiliary routines
 Version: @CHAMELEON_VERSION_MAJOR@.@CHAMELEON_VERSION_MINOR@.@CHAMELEON_VERSION_MICRO@
-Cflags: @HIPBLAS_PKGCONFIG_DEFINITIONS@ -I${includedir}
-Libs: -L${libdir} @HIPBLAS_PKGCONFIG_LIBS@
-Libs.private: @HIPBLAS_PKGCONFIG_LIBS_PRIVATE@
-Requires: @HIPBLAS_PKGCONFIG_REQUIRED@
-Requires.private: @HIPBLAS_PKGCONFIG_REQUIRED_PRIVATE@
+Cflags: @GPUHIPBLAS_PKGCONFIG_DEFINITIONS@ -I${includedir}
+Libs: -L${libdir} @GPUHIPBLAS_PKGCONFIG_LIBS@
+Libs.private: @GPUHIPBLAS_PKGCONFIG_LIBS_PRIVATE@
+Requires: @GPUHIPBLAS_PKGCONFIG_REQUIRED@
+Requires.private: @GPUHIPBLAS_PKGCONFIG_REQUIRED_PRIVATE@
diff --git a/runtime/parsec/CMakeLists.txt b/runtime/parsec/CMakeLists.txt
index 2355aa2069ee1ebbe6ce5ad33276660cc260a382..74c4d0f928a8da8041e30e918ed9aae67057b70b 100644
--- a/runtime/parsec/CMakeLists.txt
+++ b/runtime/parsec/CMakeLists.txt
@@ -130,7 +130,7 @@ add_dependencies(chameleon_parsec
   parsec_sources
 )
 if (CHAMELEON_USE_CUDA)
-  add_dependencies(chameleon_parsec cudablas_include)
+  add_dependencies(chameleon_parsec gpucublas_include)
 endif()
 
 target_include_directories(chameleon_parsec PUBLIC
@@ -148,7 +148,7 @@ target_include_directories(chameleon_parsec PRIVATE
 target_link_libraries(chameleon_parsec PRIVATE MORSE::PARSEC)
 target_link_libraries(chameleon_parsec PRIVATE coreblas)
 if(CHAMELEON_USE_CUDA)
-  target_link_libraries(chameleon_parsec PRIVATE cudablas)
+  target_link_libraries(chameleon_parsec PRIVATE gpucublas)
 endif(CHAMELEON_USE_CUDA)
 target_link_libraries(chameleon_parsec PRIVATE MORSE::M)
 
diff --git a/runtime/starpu/CMakeLists.txt b/runtime/starpu/CMakeLists.txt
index c70669ba446ec0ef40cc53c3b3cd9721310ee942..f7c00783b3e6ec08c10edf41ef9530857810c4de 100644
--- a/runtime/starpu/CMakeLists.txt
+++ b/runtime/starpu/CMakeLists.txt
@@ -276,10 +276,10 @@ add_dependencies(chameleon_starpu
 if (NOT CHAMELEON_SIMULATION)
   add_dependencies(chameleon_starpu coreblas_include)
   if (CHAMELEON_USE_CUDA)
-    add_dependencies(chameleon_starpu cudablas_include)
+    add_dependencies(chameleon_starpu gpucublas_include)
   endif()
   if (CHAMELEON_USE_HIP)
-    add_dependencies(chameleon_starpu hipblas_include)
+    add_dependencies(chameleon_starpu gpuhipblas_include)
   endif()
 endif()
 
@@ -305,10 +305,10 @@ endif()
 if (NOT CHAMELEON_SIMULATION)
   target_link_libraries(chameleon_starpu PRIVATE coreblas)
   if(CHAMELEON_USE_CUDA)
-    target_link_libraries(chameleon_starpu PRIVATE cudablas)
+    target_link_libraries(chameleon_starpu PRIVATE gpucublas)
   endif(CHAMELEON_USE_CUDA)
   if(CHAMELEON_USE_HIP)
-    target_link_libraries(chameleon_starpu PRIVATE hipblas)
+    target_link_libraries(chameleon_starpu PRIVATE gpuhipblas)
   endif(CHAMELEON_USE_HIP)
 endif(NOT CHAMELEON_SIMULATION)
 target_link_libraries(chameleon_starpu PRIVATE MORSE::M)
diff --git a/runtime/starpu/include/runtime_codelet_z.h b/runtime/starpu/include/runtime_codelet_z.h
index 673d8c5d7a6ea287ed2fa4e948c6d8820f35a00a..14f7c4e20c4b25ce01491f4274a25c721cc122ee 100644
--- a/runtime/starpu/include/runtime_codelet_z.h
+++ b/runtime/starpu/include/runtime_codelet_z.h
@@ -34,11 +34,11 @@
 #include "coreblas/coreblas_ztile.h"
 
 #if defined(CHAMELEON_USE_CUDA)
-#include "cudablas.h"
+#include "gpucublas.h"
 #endif
 
 #if defined(CHAMELEON_USE_HIP)
-#include "hipblas.h"
+#include "gpuhipblas.h"
 #endif
 
 #endif /* !defined(CHAMELEON_SIMULATION) */
diff --git a/runtime/starpu/include/runtime_codelet_zc.h b/runtime/starpu/include/runtime_codelet_zc.h
index 010da1bbbe20e8dc0fd5a61b8d965ce03e7caf4c..edbebf408b19c50c1cbc57831fbfe90dfc21d661 100644
--- a/runtime/starpu/include/runtime_codelet_zc.h
+++ b/runtime/starpu/include/runtime_codelet_zc.h
@@ -31,7 +31,7 @@
 #include "coreblas/coreblas_zc.h"
 #include "coreblas/coreblas_zctile.h"
 #if defined(CHAMELEON_USE_CUDA)
-#include "cudablas.h"
+#include "gpucublas.h"
 #endif
 #endif
diff --git a/cmake_modules/GenPkgConfig.cmake b/cmake_modules/GenPkgConfig.cmake
index 16e5e4f4708418c8b81fa5316f90ecd6e86e2b10..72fd26a5345a126aea052d612a888da7ab5dac85 100644
--- a/cmake_modules/GenPkgConfig.cmake
+++ b/cmake_modules/GenPkgConfig.cmake
@@ -74,7 +74,7 @@ ENDMACRO(CLEAN_LIB_LIST)
 
 ###
 #
 # GENERATE_PKGCONFIG_FILE: generate files chameleon.pc, coreblas.pc and cudablas.pc
 #
 ###
 MACRO(GENERATE_PKGCONFIG_FILE)
@@ -83,39 +83,39 @@ MACRO(GENERATE_PKGCONFIG_FILE)
     set(CHAMELEON_LAPACK_PKGCONFIG_DEFINITIONS "")
     set(CHAMELEON_PKGCONFIG_DEFINITIONS "")
     set(COREBLAS_PKGCONFIG_DEFINITIONS "")
-    set(CUDABLAS_PKGCONFIG_DEFINITIONS "")
-    set(HIPBLAS_PKGCONFIG_DEFINITIONS "")
+    set(GPUCUBLAS_PKGCONFIG_DEFINITIONS "")
+    set(GPUHIPBLAS_PKGCONFIG_DEFINITIONS "")
 
     # The link flags specific to this package and any required libraries
     # that don't support PkgConfig
     set(CHAMELEON_LAPACK_PKGCONFIG_LIBS "-lchameleon_lapack")
     set(CHAMELEON_PKGCONFIG_LIBS "-lchameleon")
     set(COREBLAS_PKGCONFIG_LIBS  "-lcoreblas")
-    set(CUDABLAS_PKGCONFIG_LIBS  "-lcudablas")
-    set(HIPBLAS_PKGCONFIG_LIBS  "-lhipblas")
+    set(GPUCUBLAS_PKGCONFIG_LIBS  "-lgpucublas")
+    set(GPUHIPBLAS_PKGCONFIG_LIBS  "-lgpuhipblas")
 
     # The link flags for private libraries required by this package but not
     # exposed to applications
     set(CHAMELEON_LAPACK_PKGCONFIG_LIBS_PRIVATE "")
     set(CHAMELEON_PKGCONFIG_LIBS_PRIVATE "")
     set(COREBLAS_PKGCONFIG_LIBS_PRIVATE  "")
-    set(CUDABLAS_PKGCONFIG_LIBS_PRIVATE  "")
-    set(HIPBLAS_PKGCONFIG_LIBS_PRIVATE  "")
+    set(GPUCUBLAS_PKGCONFIG_LIBS_PRIVATE  "")
+    set(GPUHIPBLAS_PKGCONFIG_LIBS_PRIVATE  "")
 
     # A list of packages required by this package
     set(CHAMELEON_LAPACK_PKGCONFIG_REQUIRED "chameleon")
     set(CHAMELEON_PKGCONFIG_REQUIRED "hqr")
     set(COREBLAS_PKGCONFIG_REQUIRED  "")
-    set(CUDABLAS_PKGCONFIG_REQUIRED  "")
-    set(HIPBLAS_PKGCONFIG_REQUIRED  "")
+    set(GPUCUBLAS_PKGCONFIG_REQUIRED  "")
+    set(GPUHIPBLAS_PKGCONFIG_REQUIRED  "")
 
     # A list of private packages required by this package but not exposed to
     # applications
     set(CHAMELEON_LAPACK_PKGCONFIG_REQUIRED_PRIVATE "")
     set(CHAMELEON_PKGCONFIG_REQUIRED_PRIVATE "")
     set(COREBLAS_PKGCONFIG_REQUIRED_PRIVATE  "")
-    set(CUDABLAS_PKGCONFIG_REQUIRED_PRIVATE  "")
-    set(HIPBLAS_PKGCONFIG_REQUIRED_PRIVATE  "")
+    set(GPUCUBLAS_PKGCONFIG_REQUIRED_PRIVATE  "")
+    set(GPUHIPBLAS_PKGCONFIG_REQUIRED_PRIVATE  "")
 
     if(CHAMELEON_SCHED_OPENMP)
         list(APPEND CHAMELEON_PKGCONFIG_LIBS -lchameleon_openmp)
@@ -144,15 +144,15 @@ MACRO(GENERATE_PKGCONFIG_FILE)
         list(APPEND CHAMELEON_PKGCONFIG_REQUIRED "coreblas")
 
         if(CHAMELEON_USE_CUDA)
-            list(APPEND CUDABLAS_PKGCONFIG_LIBS_PRIVATE ${CUDA_CUBLAS_LIBRARIES})
-            list(APPEND CUDABLAS_PKGCONFIG_REQUIRED "cuda")
-            list(APPEND CHAMELEON_PKGCONFIG_REQUIRED "cudablas")
+            list(APPEND GPUCUBLAS_PKGCONFIG_LIBS_PRIVATE ${CUDA_CUBLAS_LIBRARIES})
+            list(APPEND GPUCUBLAS_PKGCONFIG_REQUIRED "cuda")
+            list(APPEND CHAMELEON_PKGCONFIG_REQUIRED "gpucublas")
         endif()
 
         if(CHAMELEON_USE_HIP)
-            list(APPEND HIPBLAS_PKGCONFIG_LIBS_PRIVATE ${HIPBLAS_LIBRARIES})
-            list(APPEND HIPBLAS_PKGCONFIG_LIBS_PRIVATE ${HIP_LIBRARIES})
-            list(APPEND CHAMELEON_PKGCONFIG_REQUIRED "hipblas")
+            list(APPEND GPUHIPBLAS_PKGCONFIG_LIBS_PRIVATE ${HIPBLAS_LIBRARIES})
+            list(APPEND GPUHIPBLAS_PKGCONFIG_LIBS_PRIVATE ${HIP_LIBRARIES})
+            list(APPEND CHAMELEON_PKGCONFIG_REQUIRED "gpuhipblas")
         endif()
 
     endif(NOT CHAMELEON_SIMULATION)
@@ -170,10 +170,10 @@ MACRO(GENERATE_PKGCONFIG_FILE)
     CLEAN_LIB_LIST(CHAMELEON)
     CLEAN_LIB_LIST(COREBLAS)
     if(CHAMELEON_USE_CUDA)
-        CLEAN_LIB_LIST(CUDABLAS)
+        CLEAN_LIB_LIST(GPUCUBLAS)
     endif()
     if(CHAMELEON_USE_HIP)
-        CLEAN_LIB_LIST(HIPBLAS)
+        CLEAN_LIB_LIST(GPUHIPBLAS)
     endif()
 
     # Create .pc file
@@ -182,30 +182,30 @@ MACRO(GENERATE_PKGCONFIG_FILE)
     SET(_output_chameleon_file "${CMAKE_BINARY_DIR}/chameleon.pc")
     SET(_output_coreblas_file "${CMAKE_BINARY_DIR}/coreblas.pc")
     if(CHAMELEON_USE_CUDA)
-        SET(_output_cudablas_file "${CMAKE_BINARY_DIR}/cudablas.pc")
+        SET(_output_gpucublas_file "${CMAKE_BINARY_DIR}/gpucublas.pc")
     endif()
     if(CHAMELEON_USE_HIP)
-        SET(_output_hipblas_file "${CMAKE_BINARY_DIR}/hipblas.pc")
+        SET(_output_gpuhipblas_file "${CMAKE_BINARY_DIR}/gpuhipblas.pc")
     endif()
 
     # TODO: add url of CHAMELEON releases in .pc file
     CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/chameleon_lapack.pc.in" "${_output_chameleon_lapack_file}" @ONLY)
     CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/chameleon.pc.in" "${_output_chameleon_file}" @ONLY)
-    CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/coreblas.pc.in"  "${_output_coreblas_file}" @ONLY)
+    CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/coreblas.pc.in" "${_output_coreblas_file}" @ONLY)
     if(CHAMELEON_USE_CUDA)
-        CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/cudablas.pc.in"  "${_output_cudablas_file}" @ONLY)
+        CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/gpucublas.pc.in" "${_output_gpucublas_file}" @ONLY)
     endif()
     if(CHAMELEON_USE_HIP)
-        CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/hipblas.pc.in"  "${_output_hipblas_file}" @ONLY)
+        CONFIGURE_FILE("${CMAKE_CURRENT_SOURCE_DIR}/lib/pkgconfig/gpuhipblas.pc.in" "${_output_gpuhipblas_file}" @ONLY)
     endif()
 
     # installation
     # ------------
     INSTALL(FILES ${_output_chameleon_lapack_file} DESTINATION lib/pkgconfig)
     INSTALL(FILES ${_output_chameleon_file} DESTINATION lib/pkgconfig)
-    INSTALL(FILES ${_output_coreblas_file}  DESTINATION lib/pkgconfig)
-    INSTALL(FILES ${_output_cudablas_file}  DESTINATION lib/pkgconfig)
-    INSTALL(FILES ${_output_hipblas_file}  DESTINATION lib/pkgconfig)
+    INSTALL(FILES ${_output_coreblas_file} DESTINATION lib/pkgconfig)
+    INSTALL(FILES ${_output_gpucublas_file} DESTINATION lib/pkgconfig)
+    INSTALL(FILES ${_output_gpuhipblas_file} DESTINATION lib/pkgconfig)
 
 ENDMACRO(GENERATE_PKGCONFIG_FILE)
 
@@ -74,7 +74,7 @@ ENDMACRO(CLEAN_LIB_LIST)
 ###
 #
-# GENERATE_PKGCONFIG_FILE: generate files chameleon.pc, coreblas.pc and cudablas.pc
+# GENERATE_PKGCONFIG_FILE: generate files chameleon_lapack.pc, chameleon.pc, coreblas.pc and gpucublas.pc or gpuhipblas.pc
 #
 ###